const URL = "/api/info";
const RELOAD_INTERVAL = 1000;

const timeToString = (val) => {
    const hh = (val / (60 * 60 * 60)).toFixed(0).padStart(2, "0");
    const mm = ((val / (60 * 60)) % 60).toFixed(0).padStart(2, "0");
    const ss = ((val / 60) % 60).toFixed(0).padStart(2, "0");
    return `${hh}:${mm}:${ss}`;
};

const renderDungeonInfo = (dungeon) => {
    document.querySelector("#dungeon-name").innerText = dungeon.name;
    document.querySelector("#dungeon-floor").innerText = `${dungeon.floor[0]}, ${dungeon.floor[1]}, ${dungeon.floor[2]}`;
    document.querySelector("#dungeon-time").innerText = timeToString(dungeon.time);
    document.querySelector("#dungeon-turn").innerText = `現在階:${dungeon.turnFloor}、全体:${dungeon.turnAll}`;
    document.querySelector("#dungeon-randomNumber").innerText = dungeon.randomNumber;
    document.querySelector("#dungeon-killedCount").innerText = dungeon.killedCount;
};

const renderAsukaInfo = (asuka) => {
    document.querySelector("#asuka-level").innerText = asuka.level;
    document.querySelector("#asuka-hp").innerText = `${asuka.hp[1]} / ${asuka.hp[0]}`;
    document.querySelector("#asuka-power").innerText = `${asuka.power[1]} / ${asuka.power[0]}`;
    document.querySelector("#asuka-satiation").innerText = `${asuka.satiation[1]} / ${asuka.satiation[0]}`;
    document.querySelector("#asuka-experience").innerText = asuka.experience;
    document.querySelector("#asuka-gitan").innerText = asuka.gitan;
    document.querySelector("#asuka-skillPower").innerText = asuka.skillPower[0];
};

const renderItemInfo = (items) => {
    const toString = (item) => {
        if (item.type == 0 || item.type == 1) {
            // 武器・盾
            let seals = "";
            for (let i = 0; i < item.num[1]; i++) {
                if (i < item.seal.length) {
                    seals += item.seal[i];
                } else {
                    seals += "〇";
                }
            }
            return `${item.name}${item.num[0] >= 1 ? "+" : ""}${item.num[0] != 0 ? item.num[0] : ""} [${seals}]`;
        }
        if (item.type == 3 || item.type == 4 || item.type == 259 || item.type == 260 || item.type == 4098) {
            // 投擲
            return `${item.name}[${item.num[0]}]`;
        }
        if (item.type == 9) {
            // 杖
            return `${item.name}[${item.num[0]}]`;
        }
        if (item.type == 10) {
            // 壺
            // エレキ
            const pot = item.pot
                .map((potItem, index) => {
                    return `　${`${index + 1}`.padStart(2)}:${toString(potItem)}`;
                })
                .join("\n");
            return `${item.name}[${item.num[0] - item.pot.length}]\n${pot}`;
        }
        if (item.type == 11) {
            // エレキ
            let circuits = "";
            for (let i = 0; i < item.num[1]; i++) {
                if (i < item.circuit.length) {
                    circuits += item.circuit[i];
                } else {
                    circuits += "〇";
                }
            }
            return `${item.name}[${item.ereki[1]}] [${circuits}]`;
        }
        if (item.type == 12) {
            // ギタン
            return `${item.name}[${item.num[0]}]`;
        }
        return item.name;
    };

    // 削除
    const base = document.querySelector("#items");
    while (base.firstChild) {
        base.removeChild(base.firstChild);
    }
    // 追加
    items &&
        items.forEach((item, index) => {
            const elm = document.createElement("div");
            elm.className = "item";
            elm.appendChild(document.createTextNode(`${`${index + 1}`.padStart(2)}:${toString(item)}`));
            base.appendChild(elm);
        });
};

const getInfo = () => {
    return fetch(URL).then((response) => {
        if (response.status != 200) {
            throw Error(response.statusText);
        }
        return response.json();
    });
};

const start = () => {
    getInfo()
        .then((info) => {
            renderDungeonInfo(info.dungeon);
            renderAsukaInfo(info.asuka);
            renderItemInfo(info.items);
            setTimeout(start, RELOAD_INTERVAL);
        })
        .catch((e) => {
            alert(e);
            console.error(e);
        });
};

window.addEventListener("load", start);
